Stan Math Library: Main Page

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

Stan Math Library Documentation

This is the API documentation for the Stan Math Library.

### More Information

For more information, including pointers to narrative documentation, please visit Stan's home page at:

http://mc-stan.org/

[ Stan Home Page ] © 2011–2016, Stan Development Team.